"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cacheable = void 0;
const lru_cache_constants_1 = require("../lru-cache.constants");
/**
 * Marks a class as cacheable.
 *
 * This only useful if the class has multiple instances (e.g. `TRANSIENT` or `REQUEST` scoped) and you don't want the
 * same methods on different instances to share the same cache space.
 * If you have a single instance, or you want to have the shared cache for the same methods on different class
 * instances, then do not apply this decorator.
 */
function Cacheable() {
    return function (target) {
        target[lru_cache_constants_1.CACHE_INSTANCES_PROPERTY] = 0;
        return class CacheableClass extends target {
            constructor(...args) {
                super(...args);
                Object.defineProperty(CacheableClass, 'name', {
                    enumerable: false,
                    writable: false,
                    configurable: true,
                    value: target.name
                });
                Object.defineProperty(this, lru_cache_constants_1.CACHE_INSTANCE_ID_PROPERTY, {
                    enumerable: false,
                    writable: false,
                    configurable: false,
                    value: ++target[lru_cache_constants_1.CACHE_INSTANCES_PROPERTY]
                });
            }
        };
    };
}
exports.Cacheable = Cacheable;
//# sourceMappingURL=cacheable.decorator.js.map