import type { DynamicModule } from '@nestjs/common';
import type { LruCacheAsyncModuleOptions, LruCacheModuleOptions } from './interfaces/lru-cache-options.interface';
/**
 * LRU cache module.
 *
 * Must be registered using on of the following static methods:
 * - `register` - Registers the module synchronously.
 * - `registerAsync` - Registers the module asynchronously.
 */
export declare class LruCacheModule {
    /**
     * Registers the LRU cache module synchronously.
     *
     * @param options LRU cache options.
     */
    static register(options: LruCacheModuleOptions): DynamicModule;
    /**
     * Registers the LRU cache module asynchronously.
     *
     * Requires one of the following factories: `useFactory`, `useClass`, or `useExisting`.
     *
     * @param options LRU cache async options.
     */
    static registerAsync(options: LruCacheAsyncModuleOptions): Promise<DynamicModule>;
    private static _createOptionsProviders;
    private static _createOptionsProvider;
}
//# sourceMappingURL=lru-cache.module.d.ts.map